#!/usr/bin/python
# -*- coding: utf-8 -*-

def _init():
    global _global_dict
    _global_dict = {}


def set_value(name, value):
    _global_dict[name] = value


def get_value(name, defValue=None):
    try:
        return _global_dict[name]
    except KeyError:
        return defValue



#!/usr/bin/python
# -*- coding: utf-8 -*-
"""
STF_Server, get devices, connect devices
Author: 韩杰峰
"""
import os
import logging
import time
from stf_selector.selector import Selector
from stf_selector.query import where
from tinydb import TinyDB, where
from tinydb.storages import MemoryStorage
import re
import uiautomator2 as u2
import subprocess
from ReadConfig import ReadConfig
import requests

logger = logging.getLogger(__name__)
TinyDB.DEFAULT_STORAGE = MemoryStorage


class STF_Server(object):
    def __init__(self, path):
        """
        Construct method
        """
        self.path = path
        self.s = Selector(url=ReadConfig(path).get_server_url()+'/devices', token=ReadConfig(path).get_server_token())
        self.s.load()

    def devices_list(self):
        """获取平台所有设备"""
        devices = self.s.devices()
        return devices

    def ready_devices(self):
        """查找标记为ready的设备"""
        devices = self.s.find(where('ready') == True).devices()
        if len(devices) > 0:
            return devices
        else:
            return False

    def online_devices(self):
        """查找online 的设备"""
        devices = self.s.find(where('present') == True).devices()
        if len(devices) > 0:
            return devices
        else:
            return False

    def model_devices(self, model):
        """查找特定型号的设备"""
        devices = self.s.find(where('model') == model).devices()
        if len(devices) > 0:
            return devices
        else:
            return False

    def brand_devices(self, brand):
        """查找特定品牌的设备"""
        devices = self.s.find(where('brand') == brand).devices()
        if len(devices) > 0:
            return devices
        else:
            return False

    def sdk_devices(self, sdk):
        '''查找特定SDK的设备'''
        devices = self.s.find(where('sdk') == sdk).devices()
        if len(devices) > 0:
            return devices
        else:
            return False

    def version_devices(self, version):
        '''查找特定SDK的设备'''
        devices = self.s.find(where('version') == version).devices()
        if len(devices) > 0:
            return devices
        else:
            return False

    def serial_devices(self, serial):
        '''查找特定serial的设备'''
        devices = self.s.find(where('serial') == serial).devices()
        if len(devices) > 0:
            return devices
        else:
            return False

    def get_remoteurl(self, serial):
        '''查找特定serial的设备'''
        devices = self.s.find(where('serial') == serial).devices()
        if len(devices) > 0:
            return devices[0]['remoteConnectUrl']
        else:
            return False

    '''
    连接已插线设备
    '''

    def connect_usb_devices(self):
        '''get the devices usb connected on PC
        return alive devices'''
        output = subprocess.check_output(['adb', 'devices'])
        pattern = re.compile(
            r'(?P<serial>[^\s]+)\t(?P<status>device|offline)')
        matches = pattern.findall(output.decode())
        valid_serials = [m[0] for m in matches if m[1] == 'device']

        if valid_serials:
            print('连接USB设备，设备序列号 %s' % valid_serials)
            devices_list = []
            for i in valid_serials:
                try:
                    device = u2.connect_usb(i)
                    # device.healthcheck()
                    if device.alive:
                        dict_tmp = device.device_info
                        devices_list.append(dict_tmp)
                    else:
                        print('设备 %s 不可用,请检查usb链接状态!' % i)
                except Exception as e:
                    print('返回错误: %s\n 设备 %s 不可用,请检查usb链接状态!' % (e, i))
            return device
        if len(valid_serials) == 0:
            print("未发现可用的USB设备,请检查设备连接情况!")

    '''
    连接USB指定serial设备
    '''

    def connect_serial_usb_stf_devices(self, serial):
        '''
        adb connect
        '''
        self.open_stf_remote(serial)
        self.s = STF_Server(self.path)
        remote_ip = self.s.get_remoteurl(serial)
        print('远程调试IP:'.decode("utf-8").encode("gbk")+str(remote_ip))
        os.system('adb connect ' + remote_ip)
        time.sleep(10)
        '''get the devices usb connected on PC
        return alive devices'''
        output = subprocess.check_output(['adb', 'devices'])
        pattern = re.compile(
            r'(?P<serial>[^\s]+)\t(?P<status>device|offline)')
        matches = pattern.findall(output.decode())
        valid_serials = [m[0] for m in matches if m[1] == 'device']

        if valid_serials:
            print('连接USB设备，设备序列号 %s' % serial)
            devices_list = []
            try:
                device = u2.connect_usb(remote_ip)
                if device.alive:
                    dict_tmp = device.device_info
                    devices_list.append(dict_tmp)
                else:
                    print('设备 %s 不可用,请检查usb链接状态!' % serial)
            except Exception as e:
                print('返回错误: %s\n 设备 %s 不可用,请检查usb链接状态!' % (e, serial))
            return device
        if len(valid_serials) == 0:
            print('未发现可用的USB设备,请检查设备连接情况!')

    '''
    STF打开remote
    '''

    def open_stf_remote(self, serial):
        headers = {
            'Content-Type': 'application/json',
            'Authorization': 'Bearer ' + ReadConfig(self.path).get_server_token()
        }
        data = {
            'serial': serial
        }
        r = requests.post(ReadConfig(self.path).get_server_url()+'/user/devices', json=data, headers=headers)
        return r

    '''
    STF关闭remote
    '''

    def close_stf_remote(self, serial):
        headers = {
            'Authorization': 'Bearer ' + ReadConfig(self.path).get_server_token()
        }
        r = requests.request('DELETE', ReadConfig(self.path).get_server_url()+'/user/devices/' + serial,
                             headers=headers)
        return r


if __name__ == '__main__':
    # print(len(online_devices()))
    #print(model_devices(' 6T'))

    #open_stf_remote('4b89b1ce9905')
    #time.sleep(20)
    s = STF_Server()
    # remote_url = s.get_remoteurl('4b89b1ce9905')
    # print("before:"+str(remote_url))
    # s.open_stf_remote('4b89b1ce9905')
    # s = STF_Server()
    # remote_url = s.get_remoteurl('4b89b1ce9905')
    # print("after:"+str(remote_url))
    # print(s.serial_devices('4b89b1ce9905'))
    # os.system('adb connect '+remote_url)
    # time.sleep(10)
    s.connect_serial_usb_stf_devices('4b89b1ce9905')
    s.close_stf_remote('4b89b1ce9905')



#! /usr/bin/env python
# -*- encoding: utf-8 -*-

import os
import sys
import platform
import time
import json
import argparse
import shutil

__version__ = '0.0.9'
__dir__ = os.path.dirname(os.path.abspath(__file__))




def create_project(proectname):
    ywAUTpath = os.path.split(os.path.abspath(__file__))[0]+os.sep+"project"
    currentPath = os.getcwd()+os.sep
    projceDir = currentPath+proectname

    if os.path.exists(projceDir):
        print(("项目"+proectname+"在当前目录已存在,请先删除!").decode("utf-8").encode("gbk"))
    else:
        shutil.copytree(ywAUTpath, projceDir)
        print(("项目"+proectname+"新建成功！\n").decode("utf-8").encode("gbk"))


def main():
    ap = argparse.ArgumentParser(
        formatter_class=argparse.ArgumentDefaultsHelpFormatter)
    ap.add_argument('-v', action='store_true',
                    help='查看当前版本'.decode("utf-8").encode("gbk"))
    ap.add_argument('--setup','--name', type=str,
                    help='自定义名称创建测试工程'.decode("utf-8").encode("gbk"))


    args = ap.parse_args()
    if args.setup:
        create_project(sys.argv[2])
        return

    if args.v:
        print(__version__)

if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: gbk -*-

from behave import *
import ywAUT.Globalvar as gl
d = gl.get_value('device')


@step("账号密码登陆")
def step_impl(context):
    d(resourceId="com.miui.home:id/icon_icon").click()
    d(description=u"2018年12月7日,农历冬月初一,星期五").click()
    d(description=u"2018年12月8日,农历冬月初二,星期六").click()






#!/usr/bin/python
# -*- coding: gbk -*-
import os
from behave import *
from ywAUT.Driver import Driver
import ywAUT.Globalvar as gl
'''
    1. 初始化启动driver
    2. 连接设备
    3. 扩大driver作用域
    4. 引导配置文件
'''
driver = Driver(os.path.dirname(os.path.split(os.path.abspath(__file__))[0]))
d = driver.connect_device()
gl._init()
gl.set_value('device', d)


@step("安装app")
def step_impl(context):
    driver.app_install()


@step("打开app")
def step_impl(context):
    driver.app_start()


@step("关闭app")
def step_impl(context):
    driver.app_stop()
    driver.close_remote()


@step('点击包含"{key_value}"的文本')
def step_impl(context, key_value):
    d(text=key_value).click()


@step('点击包含"{key_value}"的按钮')
def step_impl(context, key_value):
    d(text=key_value).click()


@step('页面包含"{key_value}"')
def step_impl(context, key_value):
    assert d(text=key_value).wait(timeout=20)


@step('页面不包含"{key_value}"')
def step_impl(context, key_value):
    assert not d(text=key_value).wait(timeout=20)


@step('向上滑动到"{key_value}"处')
def step_impl(context, key_value):
    d(scrollable=True).scroll.to(text=key_value)


@step('向左滑动到"{key_value}"处')
def step_impl(context, key_value):
    d(scrollable=True).scroll.horiz.forward(steps=100)


@step('向"{forward}"滑动(\d+)次')
def step_impl(context, forward, time):
    for i in range(int(time)):
        if forward == '左':
            d.swipe(370, 370, 70, 370, 0)
        elif forward == '右':
            d.swipe(70, 370, 370, 370, 0)
        elif forward == '上':
            d.swipe(370, 170, 370, 570, 0)
        elif forward == '下':
            d.swipe(370, 570, 370, 170, 0)




#!/usr/bin/env python
#-*- coding:utf-8 -*-

#############################################
# File Name: setup.py
# Author: HanJieFeng
# Mail: hanjiefeng1987@126.com
# Created Time:  2018-12-12 10:17:34
#############################################

from setuptools import setup, find_packages            #这个包没有的可以pip一下

setup(
    name = "yw-AUT",      #项目发布的名称
    version = "0.0.9",  #版本号，数值大的会优先被pip
    keywords = ("pip", "SICA","featureextraction"),
    description = "An feature extraction algorithm",
    long_description = "An feature extraction algorithm, improve the FastICA",
    license = "MIT Licence",

    url = "http://git.code.oa.com/yuewen-test/u2_stf_automator.git",     #项目相关文件地址，一般是github
    author = "HanJieFeng",
    author_email = "hanjiefeng1987@126.com",

    packages = find_packages(),
    #package_data = {'ywAUT': ['project/steps/*.py', 'project/*.ini', 'project/testsuite/*.feature']},
    include_package_data = True,
    platforms = "any",
    install_requires = [
	"stf-selector",
	"behave",
	"uiautomator2",
	"pillow",
	"configparser",
	"PyYAML",
	"weditor",
	]          #这个项目需要的第三方库
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
Read config
Param:project path
Author: 韩杰峰
"""

import configparser
import os

class ReadConfig(object):
    def __init__(self, path):
        configPath = os.path.join(path, "config.ini")
        self.cf = configparser.ConfigParser()
        self.cf.read(configPath, encoding='UTF-8')

    def get_method(self):
        value = self.cf.get("DEVICES", 'method')
        return value

    def get_server_url(self):
        value = self.cf.get("DEVICES", "server")
        return value

    def get_devices_ip(self):
        value = self.cf.get("DEVICES", "IP")
        return value.split('/')

    def get_devices_serial(self):
        value = self.cf.get("DEVICES", "serial")
        return value

    def get_apk_url(self):
        value = self.cf.get("APP", "apk_url")
        return value

    def get_pkg_name(self):
        value = self.cf.get("APP", "pkg_name")
        return value

    def get_testdata(self, name):
        value = self.cf.get("TESTDATA", name)
        return value.split('/')

    def get_server_token(self):
        value = self.cf.get("DEVICES", "token")
        return value

if __name__ == '__main__':
    print(ReadConfig().get_devices_serial())
